@@ -1,11 +1,11 @@
 """
-2021: aleatoryscience
-Lys Sanz Moreta
-Draupnir : GP prior VAE for Ancestral Sequence Resurrection
+=======================
+2022: Lys Sanz Moreta
+Draupnir : Ancestral protein sequence reconstruction using a tree-structured Ornstein-Uhlenbeck variational autoencoder
 =======================
 """
 import sys
-sys.path.append("./draupnir/src/draupnir")
+#sys.path.append("./draupnir/src/draupnir")
 import Draupnir_utils as DraupnirUtils
 import warnings
 from collections import namedtuple
@@ -13,7 +13,7 @@ import pprint
 import os
 import numpy as np
 import torch
-from Bio import AlignIO, SeqIO
+from Bio import SeqIO
 import gdown
 
 def available_datasets(print_dict = False):
@@ -71,7 +71,7 @@ def create_draupnir_dataset(name,use_custom,script_dir,build=False,fasta_file=No
                             and observes all the leaf sequences. Use with datasets without ancestors for testing, only generate sequences).
         """
     BuildConfig = namedtuple('BuildConfig',['alignment_file','use_ancestral','n_test','build_graph',"aa_prob","triTSNE","leaves_testing","script_dir","no_testing"])
-    SettingsConfig = namedtuple("SettingsConfig", ["one_hot_encoding", "model_design", "aligned_seq","data_folder","full_name"])
+    SettingsConfig = namedtuple("SettingsConfig", ["one_hot_encoding", "model_design", "aligned_seq","data_folder","full_name","tree_file"])
     #script_dir = os.path.dirname(os.path.abspath(__file__))
     if not use_custom:
         warnings.warn("You have selected a pre-defined dataset, if not present, it will be downloaded. Otherwise set use_custom to True")
@@ -111,25 +111,28 @@ def create_draupnir_dataset(name,use_custom,script_dir,build=False,fasta_file=No
         # Highlight: Simulation datasets, Simulations might produce stop codons---Use probabilities == 21
         if name.startswith("simulations"):
             # DraupnirUtils.Remove_Stop_Codons("Datasets_Simulations/{}/Dataset{}/{}.txt".format(simulation_folder,dataset_number,root_sequence_name))
-            alignment_file = "{}/datasets/default/{}/{}_True_Pep_alignment.FASTA".format(script_dir,name,root_sequence_name)
+            alignment_file = "{}/{}/{}_True_Pep_alignment.FASTA".format(storage_folder,name,root_sequence_name)
+            tree_file = "{}/{}/{}_True_Rooted_tree_node_labels.tre".format(storage_folder,name,root_sequence_name)
             build_config = BuildConfig(alignment_file=alignment_file, use_ancestral=True, n_test=0, build_graph=True,aa_prob=21,triTSNE=False,leaves_testing=False,script_dir=script_dir,no_testing=False)
             if build:
                 DraupnirUtils.create_dataset(name,
                                one_hot_encoding=False,
-                               tree_file="{}/datasets/default/{}/{}_True_Rooted_tree_node_labels.tre".format(script_dir,name,root_sequence_name),
-                               alignment_file="{}/datasets/default/{}/{}_True_Pep_alignment.FASTA".format(script_dir,name,root_sequence_name),
+                               tree_file= tree_file,
+                               alignment_file="{}/{}/{}_True_Pep_alignment.FASTA".format(storage_folder,name,root_sequence_name),
                                aa_probs=21,
                                rename_internal_nodes=True,
                                storage_folder=storage_folder)
 
         elif name == "benchmark_randall_original_naming":
-            alignment_file = "{}/{}/{}/benchmark_randall_original_naming.mafft".format(script_dir,storage_folder,name)
+            alignment_file = "{}/{}/benchmark_randall_original_naming.mafft".format(storage_folder,name)
+            tree_file = "{}/RandallBenchmarkTree_OriginalNaming.tree".format(storage_folder)
             build_config = BuildConfig(alignment_file=alignment_file, use_ancestral=True, n_test=0, build_graph=True,aa_prob=21,triTSNE=False,leaves_testing=False,script_dir=script_dir,no_testing=False)
             if build:
-                benchmark_randalls_dataset_train(name, aa_prob=21)
+                benchmark_randalls_dataset_train(name, storage_folder ,aa_prob=21)
 
         elif name == "SH3_pf00018_larger_than_30aa":# Highlight: SRC Kinases, SH3 domain with PDB structures
-            alignment_file = "{}/datasets/default/SH3_pf00018_larger_than_30aa/SH3_pf00018_larger_than_30aa.mafft".format(script_dir) #I hope it's the correct one
+            alignment_file = "{}/SH3_pf00018_larger_than_30aa/SH3_pf00018_larger_than_30aa.mafft".format(storage_folder) #I hope it's the correct one
+            tree_file = "{}/SH3_pf00018_larger_than_30aa/SH3_pf00018_larger_than_30aa.mafft.treefile".format(storage_folder)
             build_config = BuildConfig(alignment_file=alignment_file,
                                        use_ancestral=False,
                                        n_test=0, #i.e n_test = 20 --> 20% sequences for testing---> use with leaves testing True
@@ -144,19 +147,20 @@ def create_draupnir_dataset(name,use_custom,script_dir,build=False,fasta_file=No
             else: assert build_config.n_test == 0; "Please do not test leaves, set n_test = 0"
             if build:
                 family_name = "PF00018;" #protein family name, src-sh3 domain
-                pfam_dict, pdb_list = DraupnirUtils.Pfam_parser(family_name,first_match=True,update_pfam=False)
-                DraupnirUtils.download_PDB(pdb_list, "/home/lys/Dropbox/PhD/DRAUPNIR/PDB_files_Draupnir_{}_{}".format(family_name.strip(";"),len(pdb_list)))
+                pfam_dict, pdb_list = DraupnirUtils.Pfam_parser(family_name,storage_folder,first_match=True,update_pfam=False)
+                DraupnirUtils.download_PDB(pdb_list, "{}/PDB_files_Draupnir_{}_{}".format(storage_folder,family_name.strip(";"),len(pdb_list)))
                 DraupnirUtils.create_dataset(name_file=name,
                                              one_hot_encoding=False,
                                              method="iqtree",
-                                             PDB_folder="{}/datasets/default/PDB_files_Draupnir_{}_{}".format(script_dir,family_name.strip(";"),len(pdb_list)),
+                                             PDB_folder="{}/PDB_files_Draupnir_{}_{}".format(storage_folder,family_name.strip(";"),len(pdb_list)),
                                              alignment_file=alignment_file,
-                                             tree_file="{}/datasets/default/SH3_pf00018_larger_than_30aa/SH3_pf00018_larger_than_30aa.mafft.treefile".format(script_dir),
+                                             tree_file=tree_file,
                                              pfam_dict=pfam_dict,
                                              rename_internal_nodes=True,
                                              storage_folder=storage_folder)
         elif name == "PF00096":#PKKinases
-            alignment_file = "{}/datasets/default/PF00096/PF00096.fasta".format(script_dir)
+            alignment_file = "{}/PF00096/PF00096.fasta".format(storage_folder)
+            tree_file = "{}/PF00096/PF00096.fasta.treefile".format(storage_folder)
             build_config = BuildConfig(alignment_file=alignment_file,
                                        use_ancestral=False,
                                        n_test=0, #Indicates the percentage of the leaves sequences for testing
@@ -171,12 +175,13 @@ def create_draupnir_dataset(name,use_custom,script_dir,build=False,fasta_file=No
                                              one_hot_encoding=False,
                                              method="iqtree",
                                              alignment_file=alignment_file,
-                                             tree_file="{}/datasets/default/PF00096/PF00096.fasta.treefile".format(script_dir),
+                                             tree_file=tree_file,
                                              rename_internal_nodes=True,
                                              min_len=0,
                                              storage_folder=storage_folder)
         elif name == "aminopeptidase":#
-            alignment_file = "{}/datasets/default/aminopeptidase/2MAT_BLAST90.fasta".format(script_dir)
+            alignment_file = "{}/aminopeptidase/2MAT_BLAST90.fasta".format(storage_folder)
+            tree_file = "{}/aminopeptidase/2MAT_BLAST90.fasta.treefile".format(storage_folder)
             build_config = BuildConfig(alignment_file=alignment_file,
                                        use_ancestral=False,
                                        n_test=0, #Indicates the percentage of the leaves sequences for testing
@@ -191,11 +196,12 @@ def create_draupnir_dataset(name,use_custom,script_dir,build=False,fasta_file=No
                                              one_hot_encoding=False,
                                              method="iqtree",
                                              alignment_file=alignment_file,
-                                             tree_file="{}/datasets/default/aminopeptidase/2MAT_BLAST90.fasta.treefile".format(script_dir),
+                                             tree_file=tree_file,
                                              rename_internal_nodes=True,
                                              storage_folder=storage_folder)
         elif name == "PF00400":
-            alignment_file = "{}/datasets/default/PF00400/PF00400.mafft".format(script_dir)
+            alignment_file = "{}/PF00400/PF00400.mafft".format(storage_folder)
+            tree_file = "{}/PF00400/PF00400.mafft.treefile".format(storage_folder)
             build_config = BuildConfig(alignment_file=alignment_file,
                                        use_ancestral=False,
                                        n_test=0,  # Indicates the percentage of the leaves sequences for testing
@@ -207,33 +213,35 @@ def create_draupnir_dataset(name,use_custom,script_dir,build=False,fasta_file=No
                                        no_testing=True)
             if build:
                 family_name = "PF00400;"  # protein family name
-                pfam_dict, pdb_list = DraupnirUtils.Pfam_parser(family_name, first_match=True, update_pfam=False)
+                pfam_dict, pdb_list = DraupnirUtils.Pfam_parser(family_name,storage_folder,first_match=True, update_pfam=False)
                 #DraupnirUtils.download_PDB(pdb_list, "/home/lys/Dropbox/PhD/DRAUPNIR/PDB_files_Draupnir_{}_{}".format(family_name.strip(";"), len(pdb_list)))
                 DraupnirUtils.create_dataset(name_file=name,
                                              one_hot_encoding=False,
                                              method="iqtree",
-                                             PDB_folder="{}/datasets/default/PDB_files_Draupnir_{}_{}".format(script_dir,
+                                             PDB_folder="{}/PDB_files_Draupnir_{}_{}".format(storage_folder,
                                                                                              family_name.strip(";"),
                                                                                              len(pdb_list)),
                                              alignment_file=alignment_file,
-                                             tree_file="{}/datasets/default/PF00400/PF00400.mafft.treefile".format(script_dir),
+                                             tree_file=tree_file,
                                              pfam_dict=pfam_dict,
                                              rename_internal_nodes=True,
                                              min_len=30,
                                              storage_folder=storage_folder)
         elif name == "Coral_Faviina":
-            alignment_file = "{}/datasets/default/Coral_Faviina/Coral_Faviina_Aligned_Protein.fasta".format(script_dir)
+            alignment_file = "{}/{}/Coral_Faviina_Aligned_Protein.fasta".format(storage_folder,name)
+            tree_file = "{}/{}/c90.PP.tree".format(storage_folder,name)
             build_config = BuildConfig(alignment_file=alignment_file,use_ancestral=False,n_test=0,build_graph=False,aa_prob=21,triTSNE=False,leaves_testing=False,script_dir=script_dir,no_testing=False)
             if build:
                 DraupnirUtils.create_dataset(name_file=name,
                                              one_hot_encoding=False,
-                                             tree_file="{}/datasets/default/Coral_Faviina/c90.PP.tree".format(script_dir),
+                                             tree_file=tree_file,
                                              alignment_file=alignment_file,
                                              aa_probs=21,
                                              rename_internal_nodes=True,
                                              storage_folder=storage_folder)
         elif name == "Coral_all":
-            alignment_file = "{}/datasets/default/Coral_all/Coral_all_Aligned_Protein.fasta".format(script_dir)
+            alignment_file = "{}/{}/Coral_all_Aligned_Protein.fasta".format(storage_folder,name)
+            tree_file = "{}/{}/c90.PP.tree".format(storage_folder,name)
             build_config = BuildConfig(alignment_file=alignment_file,
                                        use_ancestral=False,
                                        n_test=0,
@@ -246,18 +254,17 @@ def create_draupnir_dataset(name,use_custom,script_dir,build=False,fasta_file=No
             if build:
                 DraupnirUtils.create_dataset(name_file=name,
                                              one_hot_encoding=False,
-                                             tree_file="{}/datasets/default/Coral_all/c90.PP.tree".format(script_dir),
+                                             tree_file="{}/{}/c90.PP.tree".format(storage_folder,name),
                                              alignment_file=alignment_file,
                                              aa_probs=23,
                                              rename_internal_nodes=True,
                                              storage_folder=storage_folder)
         else:
              print("..................")
-             print(name)
-             raise NameError("Name not in the available default datasets")
+             raise NameError("Name {} not in the available default datasets".format(name))
 
     else:
-        warnings.warn("You have selected to use a custom dataset")
+        warnings.warn("You have selected to use a custom dataset, make sure to have at least a fasta file ready")
         root_sequence_name = None
         full_name = name
         assert any(v is not None for v in [fasta_file,alignment_file,tree_file]) != False,"Provide at least 1 file path: fasta_file or alignment_file or alignment_file + tree_file"
@@ -278,7 +285,7 @@ def create_draupnir_dataset(name,use_custom,script_dir,build=False,fasta_file=No
                 assert alignment_file is not None, "Provide at least 1 file path: alignment_file or alignment_file + tree_file"
                 storage_folder = os.path.dirname(alignment_file)
 
-            DraupnirUtils.create_dataset(name_file=name,
+            tree_file = DraupnirUtils.create_dataset(name_file=name,
                                              one_hot_encoding=False,
                                              tree_file=tree_file,
                                              alignment_file=alignment_file,
@@ -287,18 +294,18 @@ def create_draupnir_dataset(name,use_custom,script_dir,build=False,fasta_file=No
                                              rename_internal_nodes=True,
                                              storage_folder=storage_folder)
         else:
-            assert tree_file is not None, "Please provide a tree file inside datasets/custom/name or first build the tree"
-            assert alignment_file is not None, "Please provide a alignment file inside datasets/custom/name or first build the alignment"
-
+            assert tree_file is not None, "Please provide a tree file in the same folder as the alignment or fasta sequences file, or first build the tree"
+            assert alignment_file is not None, "Please provide a alignment file inside the same folder as the alignment or fasta sequences file or first build the alignment"
+            storage_folder = os.path.dirname(alignment_file)
     settings_config = SettingsConfig(one_hot_encoding=False,
                              model_design="GP_VAE",
                              aligned_seq=True,
-                             data_folder=["datasets/custom" if use_custom else "datasets/default"][0],
-                             full_name=full_name)
-
-
+                             data_folder=["{}".format(storage_folder) if use_custom else "{}/{}".format(storage_folder,name)][0],
+                             full_name=full_name,
+                             tree_file=tree_file)
     return build_config,settings_config, root_sequence_name
-def benchmark_randalls_dataset_train(name,aa_prob):
+
+def benchmark_randalls_dataset_train(name,storage_folder,aa_prob):
     """Processing of the leaves dataset from "An experimental phylogeny to benchmark ancestral sequence reconstruction"
     :param str name: project dataset name
     :param int aa_prob: amino acid probabilities"""
@@ -306,7 +313,7 @@ def benchmark_randalls_dataset_train(name,aa_prob):
     sequences_file = "benchmark_randall_original_naming/original_data/RandallExperimentalPhylogenyAASeqs.fasta"
     #Select the sequences of only the observed nodes
     full_fasta = SeqIO.parse(sequences_file, "fasta")
-    with open("datasets/default/benchmark_randall_original_naming/original_data/Randall_Benchmark_Observed.fasta", "w") as output_handle:
+    with open("{}/original_data/Randall_Benchmark_Observed.fasta".format(storage_folder), "w") as output_handle:
         observed_fasta = []
         for seq in full_fasta:
             if int(seq.id) in observed_nodes:
@@ -314,17 +321,17 @@ def benchmark_randalls_dataset_train(name,aa_prob):
         SeqIO.write(observed_fasta, output_handle, "fasta")
     DraupnirUtils.create_dataset(name,
                    one_hot_encoding=False,
-                   fasta_file="datasets/default/benchmark_randall_original_naming/original_data/Randall_Benchmark_Observed.fasta",
-                   alignment_file="datasets/default/benchmark_randall_original_naming/benchmark_randall_original.mafft",
-                   tree_file="benchmark_randall_original_naming/RandallBenchmarkTree_OriginalNaming.tree",
+                   fasta_file="{}/original_data/Randall_Benchmark_Observed.fasta",
+                   alignment_file="{}/benchmark_randall_original.mafft".format(storage_folder),
+                   tree_file="{}/RandallBenchmarkTree_OriginalNaming.tree".format(storage_folder),
                    aa_probs=aa_prob,
                    rename_internal_nodes=False)
-def benchmark_randalls_dataset_test(scriptdir,aa_probs=21):
+def benchmark_randalls_dataset_test(settings_config,aa_probs=21):
     """Processing of the internal nodes dataset from "An experimental phylogeny to benchmark ancestral sequence reconstruction
     :param str scriptdir
     :param int aa_probs"""
     internal_nodes = [21,30,37,32,31,34,35,36,33,28,29,22,23,27,24,26,25]
-    sequences_file = "{}/datasets/default/benchmark_randall_original_naming/original_data/RandallExperimentalPhylogenyAASeqs.fasta".format(scriptdir)
+    sequences_file = "{}/original_data/RandallExperimentalPhylogenyAASeqs.fasta".format(settings_config.data_folder)
     # Select the sequences of only the observed nodes
     full_fasta = SeqIO.parse(sequences_file, "fasta")
     aminoacid_names= DraupnirUtils.aminoacid_names_dict(aa_probs)
@@ -389,8 +396,8 @@ def benchmark_randalls_dataset_test(scriptdir,aa_probs=21):
 #         Dataset[i, 2:,0] = internal_fasta_dict[key][1]
 #
 #     return Dataset,internal_fasta_dict.keys(),max_lenght_internal_aligned
-def load_randalls_benchmark_ancestral_sequences(scriptdir):
-    dataset_test,internal_names_test = benchmark_randalls_dataset_test(scriptdir)
+def load_randalls_benchmark_ancestral_sequences(settings_config):
+    dataset_test,internal_names_test = benchmark_randalls_dataset_test(settings_config)
     dataset_test = np.array(dataset_test, dtype="float64")
     dataset_test = torch.from_numpy(dataset_test)
     return dataset_test,internal_names_test
@@ -409,7 +416,7 @@ def load_simulations_ancestral_sequences(name,settings_config,align_seq_len,tree
     #                                                                        aligned=settings_config.aligned_seq,
     #                                                                        align_max_len=align_seq_len,
     #                                                                        aa_probs=aa_probs)
-    ancestral_file = "{}/{}/{}/{}_pep_Internal_Nodes_True_alignment.FASTA".format(script_dir,settings_config.data_folder,name,root_sequence_name)
+    ancestral_file = "{}/{}_pep_Internal_Nodes_True_alignment.FASTA".format(settings_config.data_folder,root_sequence_name)
 
     # Select the sequences of only the observed nodes
     ancestral_fasta = SeqIO.parse(ancestral_file, "fasta")
