@@ -1,14 +1,18 @@
+"""
+=======================
+2022: Lys Sanz Moreta
+Draupnir : Ancestral protein sequence reconstruction using a tree-structured Ornstein-Uhlenbeck variational autoencoder
+=======================
+"""
 from collections import defaultdict
 import os,sys
 import numpy as np
 import pandas as pd
 import torch
 from Bio.SeqRecord import SeqRecord
-from Bio.Phylo.TreeConstruction import DistanceCalculator
 from Bio.Seq import Seq
 from Bio import SeqIO
-import re
-sys.path.append("./draupnir/draupnir")
+#sys.path.append("./draupnir/draupnir")
 import Draupnir_utils as DraupnirUtils
 import Draupnir_models_utils as DraupnirModelUtils
 import Draupnir_datasets as DraupnirDatasets
@@ -439,7 +443,7 @@ def processing(results_dir,dataset,patristic_matrix,cladistic_matrix,sorted_dist
         cladistic_matrix_full = cladistic_matrix
 
     return dataset_train,dataset_test,evolutionary_matrix_train,evolutionary_matrix_test,patristic_matrix_train,patristic_matrix_test,patristic_matrix_full, cladistic_matrix_train,cladistic_matrix_test,cladistic_matrix_full,position_test,leaves_names_test
-def pretreatment(dataset_train,patristic_matrix_full,cladistic_matrix_full,build_config):
+def pretreatment(dataset_train,patristic_matrix_full,cladistic_matrix_full,build_config,settings_config):
     """ALigns the order of the nodes in the dataset and the patristic and cladistic matrices. Calculates the amino acid frequencies.
     :param tensor dataset_train
     :param tensor patristic_matrix_full
@@ -449,7 +453,7 @@ def pretreatment(dataset_train,patristic_matrix_full,cladistic_matrix_full,build
     # Highlight: alternative aa_freqs = DraupnirUtils.calculate_aa_frequencies_torch(dataset_train[:,2:,0],freq_bins=build_config.aa_prob)
     aa_frequencies = DraupnirUtils.calculate_aa_frequencies(dataset_train[:,2:,0].cpu().detach().numpy(),freq_bins=build_config.aa_probs)
     aa_frequencies = torch.from_numpy(aa_frequencies)
-    aa_properties = DraupnirUtils.aa_properties(build_config.aa_probs,build_config.script_dir)
+    aa_properties = DraupnirUtils.aa_properties(build_config.aa_probs,settings_config.data_folder)
 
     def matrix_sort(matrix,trim=False):
         """Sorts the input matrix by the nodes indexes in ascending order"""
@@ -632,7 +636,7 @@ def datasets_pretreatment(name,root_sequence_name,train_load,test_load,additiona
                                                                                         build_config.align_seq_len,#TODO: Hopefully this is always correct
                                                                                         additional_load.tree_levelorder_names,
                                                                                         root_sequence_name,
-                                                                                        build_config.aa_prob,
+                                                                                        build_config.aa_probs,
                                                                                         script_dir)
 
         test_nodes_observed = dataset_test[:, 0, 1].tolist()
@@ -656,7 +660,7 @@ def datasets_pretreatment(name,root_sequence_name,train_load,test_load,additiona
 
 
     elif name.startswith("benchmark"):
-        dataset_test, internal_names_test = DraupnirDatasets.load_randalls_benchmark_ancestral_sequences(script_dir)
+        dataset_test, internal_names_test = DraupnirDatasets.load_randalls_benchmark_ancestral_sequences(settings_config)
         test_nodes_observed =  dataset_test[:, 0, 1].tolist()
         special_nodes_dict=None
         patristic_matrix_train, \
@@ -680,7 +684,7 @@ def datasets_pretreatment(name,root_sequence_name,train_load,test_load,additiona
         internal_names_test , \
         max_lenght_internal_aligned,\
         special_nodes_dict =DraupnirDatasets.load_coral_fluorescent_proteins_ancestral_sequences(name = name,
-                                                         ancestral_file="{}/datasets/default/{}/Ancestral_Sequences.fasta".format(script_dir,name),
+                                                         ancestral_file="{}/Ancestral_Sequences.fasta".format(settings_config.data_folder),
                                                          tree_levelorder_names =additional_load.tree_levelorder_names,
                                                          aa_probs=build_config.aa_probs)
 
@@ -755,7 +759,7 @@ def datasets_pretreatment(name,root_sequence_name,train_load,test_load,additiona
     patristic_matrix_train,\
     cladistic_matrix_full,\
     cladistic_matrix_train,\
-    aa_frequencies = pretreatment(train_load.dataset_train, additional_load.patristic_matrix_full,additional_load.cladistic_matrix_full, build_config)
+    aa_frequencies = pretreatment(train_load.dataset_train, additional_load.patristic_matrix_full,additional_load.cladistic_matrix_full, build_config,settings_config)
 
 
     test_load = TestLoad(dataset_test=dataset_test,
