@@ -1,3 +1,9 @@
+"""
+=======================
+2022: Lys Sanz Moreta
+Draupnir : Ancestral protein sequence reconstruction using a tree-structured Ornstein-Uhlenbeck variational autoencoder
+=======================
+"""
 import os, itertools,sys
 from collections import defaultdict
 import torch
@@ -9,7 +15,6 @@ import pandas as pd
 import matplotlib.pyplot as plt
 import matplotlib.pylab as pl
 import matplotlib
-from mpl_toolkits.mplot3d import Axes3D
 from Bio import SeqRecord, SeqIO
 from Bio.Seq import Seq
 import seaborn as sns
