@@ -1,4 +1,9 @@
-
+"""
+=======================
+2022: Lys Sanz Moreta
+Draupnir : Ancestral protein sequence reconstruction using a tree-structured Ornstein-Uhlenbeck variational autoencoder
+=======================
+"""
 def index_generator(indexes):
     """Call method to subsample in order.
     model (args, iter_num = index_generator())
